PipelineFut

Type Alias PipelineFut 

pub type PipelineFut<N> = Pin<Box<dyn Future<Output = (Pipeline<N>, Result<ControlFlow, PipelineError>)> + Send>>;
The future that returns the owned pipeline and the result of the pipeline run. See Pipeline::run_as_fut.

Aliased Type

pub struct PipelineFut<N> { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 16 bytes